free_result

Function free_result 

pub unsafe fn free_result(ptr: i32)
Frees a byte array pointer returned by encode.

This function is exposed for the functions that the register_source macro generates and should not be used directly.

Safety

The pointer must be a valid pointer to a byte array returned by encode.