read_string

Function read_string 

pub fn read_string(rid: i32) -> Option<String>
Reads a string from a descriptor.

This function is exposed for the functions that the register_source macro generates and should not be used directly.