pub fn parse_date_with_options<T: AsRef<str>, U: AsRef<str>, V: AsRef<str>, W: AsRef<str>>(
date_str: T,
format: U,
locale: V,
timezone: W,
) -> Option<i64>Expand description
Parses a date string into a Unix timestamp using the specified format, locale, and timezone.
The format string should be valid for Swift’s DateFormatter. The locale and timezone should be identifiers accepted by Swift’s Locale and TimeZone.